<%@ Control Language="C#" %>
<%@ Register Assembly="Telerik.Web.UI" Namespace="Telerik.Web.UI.Editor" TagPrefix="tools" %>
<%@ Register Assembly="Telerik.Web.UI" Namespace="Telerik.Web.UI.Widgets" TagPrefix="widgets" %>
<%@ Register Assembly="Telerik.Web.UI" Namespace="Telerik.Web.UI.Dialogs" TagPrefix="dialogs" %>
<%@ Register Assembly="Telerik.Web.UI" Namespace="Telerik.Web.UI" TagPrefix="telerik" %>

<script type="text/javascript">
Type.registerNamespace("Telerik.Web.UI.Widgets");

Telerik.Web.UI.Widgets.ImageProperties = function(element)
{
	Telerik.Web.UI.Widgets.ImageProperties.initializeBase(this, [element]);
	this._clientParameters = null;
	this._allowedASCII = new Array(8, 16, 35, 36, 37, 39, 45, 46);
	this._constrainDimentions = false;
	this._ratio = 0;
	this._originalImageWidth = 0;
	this._originalImageHeight = 0;
}

Telerik.Web.UI.Widgets.ImageProperties.prototype = {
	initialize: function()
	{
		Telerik.Web.UI.Widgets.ImageProperties.callBaseMethod(this, 'initialize');
		this._setupChildren();
	},

	dispose: function()
	{
		$clearHandlers(this._imageWidth);
		$clearHandlers(this._imageHeight);
		$clearHandlers(this._constrainButton);
		if (this._insertButton)
			$clearHandlers(this._insertButton);
		if (this._cancelButton)
			$clearHandlers(this._cancelButton);

		Telerik.Web.UI.Widgets.ImageProperties.callBaseMethod(this, 'dispose');
	},

	clientInit: function(clientParameters)
	{
		this._colors = clientParameters.Colors;
		this._editor = clientParameters.editor;
		this._cssClasses = clientParameters.CssClasses;
		if (!clientParameters.get_value)
		{
			return;
		}
		var originalImage = null;
		try
		{
			//prevent"Can't execude code from a freed script"
			originalImage = clientParameters.get_value();
		} catch (ex) { };
		if (originalImage)
		{
			this.loadImageProperties(originalImage);
		}
	},

	loadImageProperties: function(originalImage)
	{
		this._originalImage = originalImage;
		var currentImage = this._originalImage.cloneNode(true);

		this._imageWidth.value = this._getOriginalWidth(this._originalImage);
		this._imageHeight.value = this._getOriginalHeight(this._originalImage);
		this._ratio = this._imageWidth.value / this._imageHeight.value;

		var currentSrc = currentImage.getAttribute("src", 2);
		if (this._imageSrc)
		{
			this._imageSrc.set_value(currentSrc);
			this._imageSrc.set_editor(this._editor);
			if (this._originalImage) this._imageSrc.set_img(this._originalImage.cloneNode(true)); //NEW Stanimir: set the image that is passed to the ImageManager dialogue
			this._imageSrcValue = null;
		}
		else
		{
			this._imageSrcValue = currentSrc;
		}

		this._imageAlt.value = this._getAttribute(currentImage, "alt");
		this._imageLongDecs.value = this._getAttribute(currentImage, "longDesc");
		this._imageAlignment.setTagName("IMG");

		var floatJSProperty = ($telerik.isIE) ? "styleFloat" : "cssFloat";
		var styleFloat = (typeof (currentImage.style[floatJSProperty]) == "undefined") ? "" : currentImage.style[floatJSProperty];
		var verticalAlign = (typeof (currentImage.style["verticalAlign"]) == "undefined") ? "" : currentImage.style["verticalAlign"];
		var alignValue = "";

		if (verticalAlign == "" && styleFloat != "")
		{
			switch (styleFloat)
			{
				case "left":
					alignValue = "left";
					break;
				case "right":
					alignValue = "right";
					break;
			}
		}
		if (styleFloat == "")
		{
			switch (verticalAlign)
			{
				case "top":
					alignValue = "top";
					break;
				case "middle":
					alignValue = "absmiddle";
					break;
				case "text-bottom":
					alignValue = "bottom";
					break;
			}
		}

		this._imageAlignment.updateValue(alignValue, null);

		if (currentImage.style.marginTop)
			this._marginTopSpinBox.set_value(currentImage.style.marginTop.replace("px", ""));
		else
			this._marginTopSpinBox.set_value("");

		if (currentImage.style.marginRight)
			this._marginRightSpinBox.set_value(currentImage.style.marginRight.replace("px", ""));
		else
			this._marginRightSpinBox.set_value("");

		if (currentImage.style.marginBottom)
			this._marginBottomSpinBox.set_value(currentImage.style.marginBottom.replace("px", ""));
		else
			this._marginBottomSpinBox.set_value("");

		if (currentImage.style.marginLeft)
			this._marginLeftSpinBox.set_value(currentImage.style.marginLeft.replace("px", ""));
		else
			this._marginLeftSpinBox.set_value("");

		var borderValue = parseInt(currentImage.style.borderWidth);
		if (isNaN(borderValue)) borderValue = "";
		if (!borderValue)
		{
			var borderAttributeValue = currentImage.getAttribute("border");
			if (borderAttributeValue)
			{
				borderValue = borderAttributeValue;
				currentImage.style.borderWidth = borderAttributeValue + "px";
				currentImage.style.borderStyle = "solid";
			}
		}
		currentImage.removeAttribute("border");
		this._borderWidthSpinBox.set_value(borderValue);

		//Set colors to the color picker
		this._colorPicker.set_items(this._colors);
		var borderColor = currentImage.style.borderColor.toUpperCase();
		this._colorPicker.set_color(borderColor);

		//Set css class names to the css dropdown and selects the one of the selected image if existing
		this._imageCssClassList.set_items(this._cssClasses);

		if (currentImage.className != null && currentImage.className != "")
		{
			this._imageCssClassList.updateValue(currentImage.className);
		}
	},

	_setObjectCssProterty: function(obj, value, cssProperty, attribute)
	{
		if (cssProperty)
			obj.style[cssProperty] = value;

		if (attribute)
			obj.removeAttribute(attribute);
	},

	_setToolObjectValue: function(toolObj, currentObject, cssProperty, attribute)
	{
		var value = currentObject.style[cssProperty];
		if (attribute)
		{
			if (!value)
				value = currentObject.getAttribute(attribute);
			currentObject.removeAttribute(attribute);
		}
		toolObj.set_value(value);
	},

	_validateNumber: function(e)
	{
		if (window.event != null)
		{
			e = window.event;
		}
		if (((e.keyCode >= 48) && (e.keyCode <= 57)) ||
		((e.keyCode >= 96) && (e.keyCode <= 105)) ||
		(this._inArray(this._allowedASCII, e.keyCode)))
		{
			return true;
		}
		else
		{
			if (e.preventDefault)
			{
				e.preventDefault();
				e.stopPropagation();
			}
			return false;
		}
	},


	_inArray: function(value, code)
	{
		for (var i = 0; i < value.length; i++)
		{
			if (value[i] === code)
			{
				return true;
			}
		}
		return false;
	},

	_validateDimension: function(e, isWidthRuling)
	{
		if (!this._validateNumber(e))
		{
			return false;
		}
		if (this._constrainDimentions)
		{
			var dependantControl = null;
			var rulingControl = null;
			var ratio = 0;

			if (isWidthRuling)
			{
				dependantControl = this._imageHeight;
				rulingControl = this._imageWidth;
				ratio = 1 / this._ratio;
			}
			else
			{
				dependantControl = this._imageWidth;
				rulingControl = this._imageHeight;
				ratio = this._ratio;
			}
			dependantControl.value = Math.ceil(rulingControl.value * ratio);
		}
		return true;
	},

	_getOriginalWidth: function(currentImage)
	{
		//TODO:Set this._originalImageWidth here so we can use it later to determine whether to add it to the result image
		if (!currentImage) return "";

		//Make 4 attempts to obtain width - 1)from style, 2) from attribute 3) from client size
		var width = "";

		if (currentImage.style.width)
		{
			width = currentImage.style.width;
		}

		//Try to obtain the value from the attribute.
		if (!width)
		{
			width = currentImage.getAttribute("width");
		}

		//Try script property
		if (!width)
		{
			width = currentImage.width;
		}

		if (!width)
		{
			width = currentImage.offsetWidth;
		}

		//Convert to int
		if (width) width = parseInt(width);

		return width;
	},

	_getOriginalHeight: function(currentImage)
	{
		//TODO:Set this._originalImageHeight here so we can use it later to determine whether to add it to the result image
		if (!currentImage) return "";

		//Make 4 attempts to obtain height - 1)from style, 2) from attribute 3) from client size
		var height = "";

		if (currentImage.style.height)
		{
			height = currentImage.style.height;
		}

		//Try to obtain the value from the attribute.
		if (!height)
		{
			height = currentImage.getAttribute("height");
		}

		//Try script property
		if (!height)
		{
			height = currentImage.height;
		}

		if (!height)
		{
			height = currentImage.offsetHeight;
		}

		//Convert to int
		if (height) height = parseInt(height);

		return height;
	},

	getModifiedImage: function()
	{
		var resultImage = this._originalImage.ownerDocument.createElement("IMG");

		//Make sure the image src attribute is set before the widht/height, as setting the src causes IE to add width and height attributes expicitly
		var srcValue = this._imageSrcValue ? this._imageSrcValue : this._imageSrc.get_value();
		this._setAttribute(resultImage, "src", srcValue);

		this._setDimensionAttribute(resultImage, "width", this._imageWidth.value);
		this._setDimensionAttribute(resultImage, "height", this._imageHeight.value);
		this._setAttribute(resultImage, "alt", this._imageAlt.value);
		this._setAttribute(resultImage, "longDesc", this._imageLongDecs.value);

		//image align
		this._setImgAlignStyle(resultImage, this._imageAlignment.getAlign());

		var marginTop = parseInt(this._marginTopSpinBox.get_value());
		resultImage.style.marginTop = (!isNaN(marginTop)) ? marginTop + "px" : "";

		var marginRight = parseInt(this._marginRightSpinBox.get_value());
		resultImage.style.marginRight = (!isNaN(marginRight)) ? marginRight + "px" : "";

		var marginBottom = parseInt(this._marginBottomSpinBox.get_value());
		resultImage.style.marginBottom = (!isNaN(marginBottom)) ? marginBottom + "px" : "";

		var marginLeft = parseInt(this._marginLeftSpinBox.get_value());
		resultImage.style.marginLeft = (!isNaN(marginLeft)) ? marginLeft + "px" : "";

		var borderSize = parseInt(this._borderWidthSpinBox.get_value());
		if (!isNaN(borderSize) && borderSize >= 0)
		{
			resultImage.style.borderWidth = borderSize + "px";
			resultImage.style.borderStyle = "solid";
		}
		else
		{
			resultImage.style.borderWidth = "";
			resultImage.style.borderStyle = "";
		}
		resultImage.removeAttribute("border");

		if (this._colorPicker.get_color())
		{
			resultImage.style.borderColor = this._colorPicker.get_color();
		}

		this._setClass(resultImage, this._imageCssClassList);

		return resultImage;

	},

	_setImgAlignStyle: function(img, align)
	{
		var floatJSProperty = ($telerik.isIE) ? "styleFloat" : "cssFloat";
		switch (align)
		{
			case "left":
				img.style[floatJSProperty] = "left";
				img.style["verticalAlign"] = "";
				break;
			case "right":
				img.style[floatJSProperty] = "right";
				img.style["verticalAlign"] = "";
				break;
			case "top":
				img.style[floatJSProperty] = "";
				img.style["verticalAlign"] = "top";
				break;
			case "bottom":
				img.style[floatJSProperty] = "";
				img.style["verticalAlign"] = "text-bottom";
				break;
			case "absmiddle":
				img.style[floatJSProperty] = "";
				img.style["verticalAlign"] = "middle";
				break;
			default:
				img.style[floatJSProperty] = "";
				img.style["verticalAlign"] = "";
				break;
		}
		img.removeAttribute("align");
	},

	_setDimensionAttribute: function(image, attributeName, attributeValue)
	{
		image.removeAttribute(attributeName);

		if (image.style.removeAttribute)
		{
			image.style.removeAttribute(attributeName, false);
		}
		else
		{
			image.style[attributeName] = null;
		}

		var size = parseInt(attributeValue);
		//TODO: Use this._originalImageHeight and this._originalImageWidth here to determine whether to set attribute or not.
		if (size)
		{
			image.style[attributeName] = size + "px";
		}
	},

	_isValueValid: function(value)
	{
		var valueInt = parseInt(value, 10);

		if (!isNaN(valueInt))
		{
			var isValidPercent = (valueInt + '%' == value);
			var isValidPixel = (valueInt + 'px' == value.toLowerCase());
			var isValidNumber = (valueInt.toString() == value);
			if (isValidPercent || isValidPixel || isValidNumber)
			{
				return true;
			}
		}

		return false;
	},

	_setIntAttribute: function(image, attributeName, attributeValue)
	{
		var intAttributeValue = parseInt(attributeValue);

		if (!isNaN(intAttributeValue) && intAttributeValue >= 0)
		{
			image[attributeName] = intAttributeValue;
		}
		else
		{
			image.removeAttribute(attributeName, false);
		}
	},

	_getAttribute: function(image, attributeName)
	{
		var attributeValue = "";

		if (image.getAttribute(attributeName))
		{
			attributeValue = image.getAttribute(attributeName);
		}

		return attributeValue;
	},

	_setAttribute: function(image, attributeName, attributeValue)
	{
		if (attributeValue.trim())
		{
			image.setAttribute(attributeName, attributeValue);
		}
		else
		{
			image.removeAttribute(attributeName, false);
		}
	},

	_setClass: function(element, cssClassHolder)
	{
		if (cssClassHolder.get_value() == "")
		{
			element.removeAttribute("className");
		}
		else
		{
			element.className = cssClassHolder.get_value();
		}
	},

	_setupChildren: function()
	{
		this._imageWidth = $get("ImageWidth");
		this._imageHeight = $get("ImageHeight");
		this._constrainButton = $get("ConstrainButton");
		this._colorPicker = $find("BorderColor");
		this._imageAlignment = $find("ImageAlignment");
		this._imageAlt = $get("ImageAlt");
		this._imageLongDecs = $get("ImageLongDesc");
		this._imageSrc = $find("ImageSrc");
		this._marginTopSpinBox = $find("marginTop");
		this._marginRightSpinBox = $find("marginRight");
		this._marginBottomSpinBox = $find("marginBottom");
		this._marginLeftSpinBox = $find("marginLeft");
		this._borderWidthSpinBox = $find("ImageBorderWidth");
		this._imageCssClassList = $find("ImageCssClass");

		this._insertButton = $get("InsertButton");
		if (this._insertButton)
			this._insertButton.title = localization["OK"];
		this._cancelButton = $get("CancelButton");
		if (this._cancelButton)
			this._cancelButton.title = localization["Cancel"];

		this._initializeChildEvents();
	},

	_initializeChildEvents: function()
	{
		$addHandlers(this._imageWidth, { "keyup": this._validateDimensionByWidth }, this);
		$addHandlers(this._imageWidth, { "keydown": this._validateNumber }, this);
		$addHandlers(this._imageHeight, { "keyup": this._validateDimensionByHeight }, this);
		$addHandlers(this._imageHeight, { "keydown": this._validateNumber }, this);
		$addHandlers(this._constrainButton, { "click": this._constrainClickHandler }, this);
		if (this._insertButton)
			$addHandlers(this._insertButton, { "click": this._insertClickHandler }, this);
		if (this._cancelButton)
			$addHandlers(this._cancelButton, { "click": this._cancelClickHandler }, this);
	},

	_constrainClickHandler: function(e)
	{
		this._constrainDimentions = !this._constrainDimentions;

		if (this._constrainDimentions)
		{
			this._imageHeight.value = Math.ceil(this._imageWidth.value / this._ratio);
			Sys.UI.DomElement.addCssClass(this._constrainButton.parentNode, "toggle");
		}
		else
		{
			Sys.UI.DomElement.removeCssClass(this._constrainButton.parentNode, "toggle");
		}

		//needed to cancel the postback that the button causes in FF
		return $telerik.cancelRawEvent(e);
	},

	_validateDimensionByWidth: function(e)
	{
		this._validateDimension(e, true);
	},

	_validateDimensionByHeight: function(e)
	{
		this._validateDimension(e, false);
	},

	_insertClickHandler: function(e)
	{
		var arg = new Telerik.Web.UI.EditorCommandEventArgs("SetImageProperies", null, this.getModifiedImage())
		Telerik.Web.UI.Dialogs.CommonDialogScript.get_windowReference().close(arg);
	},

	_cancelClickHandler: function(e)
	{
		Telerik.Web.UI.Dialogs.CommonDialogScript.get_windowReference().close();
	}
}

Telerik.Web.UI.Widgets.ImageProperties.registerClass('Telerik.Web.UI.Widgets.ImageProperties', Telerik.Web.UI.RadWebControl, Telerik.Web.IParameterConsumer);
</script>

<table cellspacing="0" cellpadding="0" border="0" class="reDialog ImageProperties"
	style="width: 300px;">
	<tr>
		<td>
			<table cellpadding="0" cellspacing="0" class="reControlsLayout">
				<tr>
					<td colspan="2">
						<!-- height, width and constrain proportions button -->
						<table cellpadding="0" cellspacing="0" class="reConstrainProportionsWrapper">
							<tr>
								<td class="reLabelCell" style="width: 120px;">
									<label class="reDialogLabel">
										<span style="text-align: right;">
											<script type="text/javascript">document.write(localization["Width"]);</script>
										</span>
									</label>
								</td>
								<td class="reControlCell">
									<input type="text" id="ImageWidth" style="width: 26px; text-align: right;" />
								</td>
								<td>
									px
								</td>
								<td rowspan="2">
									<ul>
										<li class="ConstrainProportions">
											<button id="ConstrainButton" class="ConstrainButton">
												&nbsp;</button>
										</li>
									</ul>
								</td>
							</tr>
							<tr>
								<td class="reLabelCell" style="width: 120px;">
									<label class="reDialogLabel">
										<span style="text-align: right;">
											<script type="text/javascript">document.write(localization["Height"]);</script>
										</span>
									</label>
								</td>
								<td class="reControlCell">
									<input type="text" id="ImageHeight" style="width: 26px; text-align: right;" />
								</td>
								<td>
									px
								</td>
							</tr>
						</table>
						<!-- end of height, width and constrain proportions button -->
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["BorderColor"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<tools:ColorPicker ID="BorderColor" runat="Server" />
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["BorderWidth"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<tools:EditorSpinBox ID="ImageBorderWidth" runat="server" />
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["ImageAltText"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<input type="text" id="ImageAlt" style="width: 165px;" />
					</td>
				</tr>
				<tr class="textAttributes">
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["LongDescription"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<input type="text" id="ImageLongDesc" style="width: 165px;" />
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["ImageAlignment"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<tools:AlignmentSelector ID="ImageAlignment" runat="Server" />
					</td>
				</tr>
				<tr class="imageSrc" id="imageCallerRow" runat="server">
					<td class="reLabelCell">
						<label class="reDialogLabel" style="width: 120px;">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["ImageSrc"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<tools:ImageDialogCaller ID="ImageSrc" runat="server" />
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">Margin </span>
						</label>
					</td>
					<td class="reControlCell setMarginsCell">
						<table cellpadding="0" cellspacing="2" class="setMarginsTable">
							<tr>
								<td>
									<script type="text/javascript">
										document.write(localization["Top"]);
									</script>
								</td>
								<td>
									<tools:EditorSpinBox ID="marginTop" runat="server" />
								</td>
								<td>
									<script type="text/javascript">
										document.write(localization["Right"]);
									</script>
								</td>
								<td>
									<tools:EditorSpinBox ID="marginRight" runat="server" />
								</td>
							</tr>
							<tr>
								<td>
									<script type="text/javascript">
										document.write(localization["Bottom"]);
									</script>
								</td>
								<td>
									<tools:EditorSpinBox ID="marginBottom" runat="server" />
								</td>
								<td>
									<script type="text/javascript">
										document.write(localization["Left"]);
									</script>
								</td>
								<td>
									<tools:EditorSpinBox ID="marginLeft" runat="server" />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td class="reLabelCell" style="width: 120px;">
						<label class="reDialogLabel">
							<span style="text-align: right;">
								<script type="text/javascript">
									document.write(localization["CssClass"]);
								</script>
							</span>
						</label>
					</td>
					<td class="reControlCell">
						<tools:ApplyClassDropDown ID="ImageCssClass" runat="Server" />
					</td>
				</tr>
				<tr id="controlButtonsRow" runat="server">
					<td class="reBottomcell" colspan="2">
						<table border="0" cellpadding="0" cellspacing="0" class="reConfirmCancelButtonsTbl">
							<tr>
								<td>
									<button type="button" id="InsertButton">
										<script type="text/javascript">
											setInnerHtml("InsertButton", localization["OK"]);
										</script>
									</button>
								</td>
								<td>
									<button type="button" id="CancelButton">
										<script type="text/javascript">
											setInnerHtml("CancelButton", localization["Cancel"]);
										</script>
									</button>
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
